ChangeLog
=========

v1.1.1 (2018-01-11)
------------------

* Add test module

Bugs fixed:

* Rename the file name of filtered biased peaks



v1.1 (2017-11-07)
----------------

Improvements:

* Refactor the package for better performance and compatibility

Bugs fixed:

* Fix the coordinates of peaks to be consistent with the corresponding coordinate system
* Fix the approximate equation in p-value calculation
* Fix the summit calculation of merged common peaks
 